
## CATO-CLI - object list queries:

### Usage for site.search:

`cato site list -h`

`cato site list <accountID> <json>`

`cato site list 12345 -s=yourSearch`

`cato site list 12345 -s=yourSearch -f=json -p`

#### Operation Arguments for mutation.admin.addAdmin ####
`accountId` [ID] - (required) N/A 
`search` [String] - (required) N/A 
